@@ -142,9 +142,7 @@ class TaskAssignator:
                 coromask(
                     self.new_process,
                     args, {},
-                    simple_fargs_out),
-                name="task_new_process"
-            )
+                    simple_fargs_out))
             #
             task.add_done_callback(
                 functools.partial(
